netapp_ontap.models.aggregate_inode_attributes API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_inode_attributes`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateInodeAttributesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateInodeAttributes object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_private_capacity: Size GET POST PATCH`

    Number of files that can currently be stored on disk for system metadata files. This number will dynamically increase as more system files are created. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 31136

  `file_public_capacity: Size GET POST PATCH`

    Number of files that can currently be stored on disk for user-visible files. This number will dynamically increase as more user-visible files are created. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 31136

  `files_private_used: Size GET POST PATCH`

    Number of system metadata files used. If the referenced file system is restricted or offline, a value of 0 is returned. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 502

  `files_total: Size GET POST PATCH`

    Maximum number of user-visible files that this referenced file system can currently hold. If the referenced file system is restricted or offline, a value of 0 is returned.

    Example: 31136

  `files_used: Size GET POST PATCH`

    Number of user-visible files used in the referenced file system. If the referenced file system is restricted or offline, a value of 0 is returned.

    Example: 97

  `max_files_available: Size GET POST PATCH`

    The count of the maximum number of user-visible files currently allowable on the referenced file system.

    Example: 31136

  `max_files_possible: Size GET POST PATCH`

    The largest value to which the maxfiles-available parameter can be increased by reconfiguration, on the referenced file system.

    Example: 2844525

  `max_files_used: Size GET POST PATCH`

    The number of user-visible files currently in use on the referenced file system.

    Example: 97

  `used_percent: Size GET POST PATCH`

    The percentage of disk space currently in use based on user-visible file count on the referenced file system.

    Example: 5

  `version: Size GET POST PATCH`

    The inofile-version of the aggregate. If the referenced file system is restricted or offline, a value of 0 is returned. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either footprint or **.

    Example: 4